<?php

//
// Short code that offers specified products on carts that don't contain it already.
//

add_action( 'admin_menu', function() {

	add_submenu_page(
		'themes.php',
		__( 'Reusable blocks', 'ccom-upsell-trio' ),
		__( 'Reusable blocks', 'ccom-upsell-trio' ),
		'manage_options',
		'edit.php?post_type=wp_block'
	);

} );

add_action( 'woocommerce_before_cart', function() {
	echo do_shortcode( '[ccom_order_bump]' );
} );

add_action( 'woocommerce_before_checkout_form', function() {
	echo do_shortcode( '[ccom_order_bump]' );
} );

add_shortcode( 'ccom_order_bump', function( $atts ) {

	// WooCommerce Or Bail
	if( ! class_exists( 'WooCommerce' ) ) {
		return;
	}

	// Front End Or Bail
	if( is_admin() ) {
		return;
	}

	// Bail On Null Or Empty Cart
	if( is_null( WC()->cart ) || WC()->cart->is_empty() ) {
		return;
	}

	// Query Reusable Blocks
	$args = [
		'limit' => -1,
		'post_type' => 'wp_block',
		'status' => 'publish',
	];
	$blocks = get_posts( $args );

	// Loop Blocks
	foreach( $blocks as $block ) {

		// Skip If Title Does Not Contain Our Separator
		if( stristr( $block->post_title, ' -for- ' ) === false ) {
			continue;
		}

		// Get Upsell And Trigger Products
		list( $upsell_product_names, $trigger_product_name )
			= explode( ' -for- ', $block->post_title );
		$upsell_product_names = explode( ' -and- ', $upsell_product_names );

		// Match Trigger Product
		$trigger_product = false;
		foreach( WC()->cart->get_cart() as $cart_item ) {
			$cart_item_product =  wc_get_product( $cart_item['data']->get_id() );
			if( $cart_item_product->get_title() === $trigger_product_name ) {
				$trigger_product = true;
			}
		}
		if( ! $trigger_product ) {
			continue;
		}

		// Upsell Products Must Not Be On Cart
		foreach( $upsell_product_names as $upsell_product_name ) {
			foreach( WC()->cart->get_cart() as $cart_item ) {
				$cart_item_product =  wc_get_product( $cart_item['data']->get_id() );
				if( $cart_item_product->get_title() === $upsell_product_name ) {
					continue 3;
				}
			}
		}

		// Output Order Bump
		return apply_filters( 'the_content', $block->post_content );

	}

} );